@@ -8,6 +8,8 @@ entry point
 import os
 import sys
 
+import shutil
+
 # local imports
 from dotdrop.options import Options
 from dotdrop.logger import Logger
@@ -16,7 +18,7 @@ from dotdrop.installer import Installer
 from dotdrop.updater import Updater
 from dotdrop.comparator import Comparator
 from dotdrop.utils import get_tmpdir, remove, strip_home, \
-    run, uniq_list, patch_ignores
+    run, uniq_list, patch_ignores, dependencies_met
 from dotdrop.linktypes import LinkTypes
 from dotdrop.exceptions import YamlException
 
@@ -209,6 +211,7 @@ def cmd_compare(o, tmp):
     t = Templategen(base=o.dotpath, variables=o.variables,
                     func_file=o.func_file, filter_file=o.filter_file,
                     debug=o.debug)
+    tvars = t.add_tmp_vars()
     inst = Installer(create=o.create, backup=o.backup,
                      dry=o.dry, base=o.dotpath,
                      workdir=o.workdir, debug=o.debug,
@@ -217,11 +220,16 @@ def cmd_compare(o, tmp):
     comp = Comparator(diff_cmd=o.diff_command, debug=o.debug)
 
     for dotfile in selected:
+        # add dotfile variables
+        t.restore_vars(tvars)
+        newvars = dotfile.get_dotfile_variables()
+        t.add_tmp_vars(newvars=newvars)
+
         if o.debug:
             LOG.dbg('comparing {}'.format(dotfile))
         src = dotfile.src
         if not os.path.lexists(os.path.expanduser(dotfile.dst)):
-            line = '=> compare {}: \"{}\" does not exist on local'
+            line = '=> compare {}: \"{}\" does not exist on destination'
             LOG.log(line.format(dotfile.key, dotfile.dst))
             same = False
             continue
@@ -415,15 +423,15 @@ def cmd_importer(o):
                     LOG.err('importing \"{}\" failed!'.format(path))
                     ret = False
                     continue
-            cmd = ['cp', '-R', '-L', dst, srcf]
             if o.dry:
-                LOG.dry('would run: {}'.format(' '.join(cmd)))
+                LOG.dry('would copy {} to {}'.format(dst, srcf))
             else:
-                r, _ = run(cmd, raw=False, debug=o.debug, checkerr=True)
-                if not r:
-                    LOG.err('importing \"{}\" failed!'.format(path))
-                    ret = False
-                    continue
+                if os.path.isdir(dst):
+                    if os.path.exists(srcf):
+                        shutil.rmtree(srcf)
+                    shutil.copytree(dst, srcf)
+                else:
+                    shutil.copy2(dst, srcf)
         retconf = o.conf.new(src, dst, linktype)
         if retconf:
             LOG.sub('\"{}\" imported'.format(path))
@@ -648,6 +656,13 @@ def main():
     if o.debug:
         LOG.dbg('\n\n')
 
+    # check dependencies are met
+    try:
+        dependencies_met()
+    except Exception as e:
+        LOG.err(e)
+        return False
+
     ret = True
     try:
 
